@@ -3,8 +3,6 @@
 #include <qtforkawesome/renderer.h>
 #include <qtforkawesome/utils.h>
 
-#include <qtutilities/misc/compat.h>
-
 #include <QGuiApplication>
 #include <QPalette>
 
@@ -22,23 +20,29 @@ QuickImageProvider::QuickImageProvider(
 
 QPixmap QuickImageProvider::requestPixmap(const QString &id, QSize *size, const QSize &requestedSize)
 {
-    const auto parts = QtUtilities::splitRef(id, QChar(':'));
+    const auto parts = QStringView(id).split(QChar(':'));
     if (parts.empty()) {
         return QPixmap();
     }
-    const auto icon = iconFromId(parts.front().toString());
+    const auto icon = iconFromId(parts.front());
     if (!isIconValid(icon)) {
         return QPixmap();
     }
-    auto color = parts.size() > 1 ? QColor(parts.at(1).toString()) : m_defaultColor;
+    auto color = m_defaultColor;
+    if (parts.size() > 1) {
+        if (const auto specifiedColor = QColor(parts.at(1)); specifiedColor.isValid()) {
+            color = specifiedColor;
+        }
+    }
     if (!color.isValid()) {
         color = QGuiApplication::palette().color(QPalette::Normal, QPalette::Text);
     }
     const auto renderSize = requestedSize.isValid() ? requestedSize : m_defaultSize;
+    const auto scaleFactor = requestedSize.isValid() ? 1.0 : 0.0;
     if (size) {
         *size = renderSize;
     }
-    return m_renderer.pixmap(icon, renderSize, color);
+    return m_renderer.pixmap(icon, renderSize, color, scaleFactor);
 }
 
 QImage QuickImageProvider::requestImage(const QString &id, QSize *size, const QSize &requestedSize)
